==> facebook-nodejs-business-sdk-4.0.8.tgz: package/docs/BUSINESS_ACCESS_TOKEN_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Business = bizSdk.Business;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
let child_business_id = '91030447373044';
let app_id_for_onboarding = '185533902045623';
const api = bizSdk.FacebookAdsApi.init(
  partner_access_token
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [BUSINESS_ACCESS_TOKEN_CREATE]
//  _DOC vars [partner_access_token]
//  _DOC vars [child_business_id]
//  _DOC vars [app_id_for_onboarding]
fields = [
];
params = {
  'app_id' : app_id_for_onboarding,
  'scope' : 'ads_management,business_management',
};
let access_token = await (new Business(child_business_id)).createAccessToken(
  fields,
  params
);

//  _DOC close [BUSINESS_ACCESS_TOKEN_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();

==> facebook-nodejs-business-sdk-6.0.0.tgz: package/docs/BUSINESS_ACCESS_TOKEN_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Business = bizSdk.Business;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
let child_business_id = '91030447373044';
let app_id_for_onboarding = '185533902045623';
const api = bizSdk.FacebookAdsApi.init(
  partner_access_token,
  crash_log=false
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [BUSINESS_ACCESS_TOKEN_CREATE]
//  _DOC vars [partner_access_token]
//  _DOC vars [child_business_id]
//  _DOC vars [app_id_for_onboarding]
fields = [
];
params = {
  'app_id' : app_id_for_onboarding,
  'scope' : 'ads_management,business_management',
};
let access_token = await (new Business(child_business_id)).createAccessToken(
  fields,
  params
);

//  _DOC close [BUSINESS_ACCESS_TOKEN_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();
